@@ -1,5 +1,6 @@
 import graphene
 from django.db.models import OuterRef, Subquery
+from django_filters.rest_framework import BooleanFilter
 
 from ..caluma_core.filters import (
     CharFilter,
@@ -200,16 +201,27 @@ class WorkItemFilterSet(MetaFilterSet):
     case_document_has_answer = HasAnswerFilter(document_id="case__document__pk")
     case_meta_value = JSONValueFilter(field_name="case__meta")
 
+    tasks = SlugMultipleChoiceFilter(field_name="task_id")
+
+    has_deadline = BooleanFilter(
+        field_name="deadline", lookup_expr="isnull", exclude=True
+    )
+    case_family = GlobalIDFilter(field_name="case__family")
+
     class Meta:
         model = models.WorkItem
         fields = (
             "status",
             "name",
             "task",
+            "tasks",
             "case",
             "created_at",
             "closed_at",
             "modified_at",
+            "deadline",
+            "has_deadline",
+            "case_family",
         )
 
 
